@@ -42,6 +42,7 @@ class GotErrorField(Exception):
 class BoolAction(argparse.Action):
     reTrue = re.compile("^(?:on)$", re.I)
     reFalse = re.compile("^(?:off)$", re.I)
+    available_values = ("on", "off")
 
     def __init__(self, option_strings, dest, nargs="?",
                  const=None, default=None, type=None, choices=None,
@@ -52,19 +53,27 @@ class BoolAction(argparse.Action):
             type=type, choices=choices, required=required,
             help=help, metavar=metavar)
 
+    def get_values(self, value):
+        value = value.lower()
+        for v in self.available_values:
+            if value == v:
+                return v
+        else:
+            return ""
+
     def __call__(self, parser, ns, values, option_string=None):
         if values is None:
             values = "on"
         else:
-            if self.reTrue.match(values):
-                values = "on"
-            elif self.reFalse.match(values):
-                values = "off"
-            else:
-                msg = _('the value may be on or off')
+            values = self.get_values(values)
+            if not values:
+                msg = _('the value may be {0}').format(
+                    formatListOr(self.available_values))
                 parser.error(msg)
         setattr(ns, self.dest, values)
 
+class BoolAutoAction(BoolAction):
+    available_values = ("on", "off", "auto")
 
 def _print(*args):
     print " ".join(map(lambda x: _u8(x), args))
@@ -130,7 +139,7 @@ def _getattr(obj, attr):
 
 import argparse
 import textwrap as _textwrap
-from calculate.lib.utils.text import get_term_size, _u, _u8, _uu8
+from calculate.lib.utils.text import get_term_size, _u, _u8, _uu8, formatListOr
 
 
 class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
@@ -221,7 +230,10 @@ def get_method_argparser(view, args, cl_core=False):
                 else:
                     data['type'] = str
                 if field.element in ['check', 'check_tristate']:
-                    data['action'] = BoolAction
+                    if field.element == "check_tristate":
+                        data['action'] = BoolAutoAction
+                    else:
+                        data['action'] = BoolAction
                     if field.value == 'on':
                         data['help'] = data['help'] + " " + _(
                             "(enabled by default)")
@@ -243,10 +255,18 @@ def get_method_argparser(view, args, cl_core=False):
                     # if ':' in data['metavar']:
                     #    data['metavar'] = field.name.upper()
                     if "choice" in field.type:
-                        data['help'] = "%s (%s)" % (
-                            data['help'],
-                            _("'list' for displaying possible values"))
-                if "bool" in field.type:
+                        if "list" in field.type:
+                            data['help'] = "%s (%s)" % (
+                                data['help'],
+                                _("'list' for displaying possible values, "
+                                  "'none' is never one"))
+                        else:
+                            data['help'] = "%s (%s)" % (
+                                data['help'],
+                                _("'list' for displaying possible values"))
+                if "boolauto" in field.type:
+                    data['metavar'] = "ON/OFF/AUTO"
+                elif "bool" in field.type:
                     data['metavar'] = "ON/OFF"
                 try:
                     opts = filter(None, [opt.shortopt, opt.longopt])
@@ -495,30 +515,24 @@ def collect_object(client, param_object, view, args, wait_thread=None,
     view = ViewInfoAdapter.from_detect(view)
     for group in view.groups:
         for field in group.fields:
-            if field.uncompatible:
-                continue
+            #if field.uncompatible:
+            #    continue
             if (field.element in ['check', 'check_tristate'] and
-                        field.type == 'bool'):
-                set_flag = False
-                if not set_flag:
-                    value = _getattr(args, field.name)
-                    if value:
-                        if _getattr(args, field.name).lower() in ['on', 'yes']:
-                            value = True
-                        elif _getattr(args,
-                                      field.name).lower() in ['off', 'no']:
-                            value = False
-                        else:
-                            value = None
+                        field.type in ('bool', 'boolauto')) or (
+                            field.element == 'radio' and field.type == 'bool'):
+                value = _getattr(args, field.name)
+                if value:
+                    if _getattr(args, field.name).lower() in ['on', 'yes']:
+                        value = True
+                    elif _getattr(args,
+                                  field.name).lower() in ['off', 'no']:
+                        value = False
                     else:
                         value = None
-                    param_object = set_obj_item(client, param_object,
-                                                field.name, value)
-
-            if field.element == 'radio' and field.type == 'bool':
-                param_object = set_obj_item(client, param_object, field.name,
-                                            _getattr(args, field.name))
-
+                else:
+                    value = None
+                param_object = set_obj_item(client, param_object,
+                                            field.name, value)
             elif (field.element == 'input' and
                           field.name in ['cl_page_offset', 'cl_page_count']):
                 val = _getattr(args, field.name)
@@ -534,7 +548,7 @@ def collect_object(client, param_object, view, args, wait_thread=None,
                                    'file', 'radio', 'combo', 'comboEdit']:
                 param_object = set_obj_item(client, param_object, field.name,
                                             _getattr(args, field.name))
-            elif 'passwd' in field.element and _getattr(args, field.name) \
+            elif 'passw' in field.element and _getattr(args, field.name) \
                     or field.type and "need" in field.type:
                 if wait_thread:
                     wait_thread.pause()
