@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -29,6 +29,9 @@ import server.certificate as certificate
 import server.groups as groups
 import server.request as request
 import set_vars
+from backup import Backup, BackupError
+from calculate.core.utils.cl_backup import ClBackupAction
+from calculate.core.utils.cl_backup_restore import ClBackupRestoreAction
 from calculate.core.server.func import WsdlBase
 from calculate.core.utils.cl_core_setup import ClCoreSetupAction
 from calculate.core.utils.cl_core_patch import ClCorePatchAction
@@ -42,6 +45,7 @@ from calculate.core.utils.cl_core_variables import (ClCoreVariables,
                                                     ClCoreVariablesShow)
 from calculate.core.utils.cl_core_custom import ClCoreCustomAction
 from calculate.core.utils.cl_core_restart import ClCoreRestartAction
+from calculate.core.variables.action import Actions
 
 
 class Wsdl(WsdlBase):
@@ -57,7 +61,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Configure a Package"),
             # иконка для графической консоли
-            'image': 'preferences-desktop-default-applications',
+            'image': 'calculate-core-setup,'
+                     'preferences-desktop-default-applications',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -89,7 +94,7 @@ class Wsdl(WsdlBase):
                                             'cl_core_pkg_root_set',
                                             'cl_verbose_set',
                                             'cl_dispatch_conf'),
-                                    next_label=_("Perform"))]},
+                                    next_label=_("Run"))]},
         #
         # Патч исходников пакета (cl-core-patch)
         #
@@ -101,7 +106,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Patch"),
             # иконка для графической консоли
-            'image': 'system-run,system,computer',
+            'image': None,
             # метода нет в графической консоли
             'gui': False,
             # консольная команда
@@ -130,7 +135,7 @@ class Wsdl(WsdlBase):
                                             'cl_core_arch_machine',
                                             'cl_templates_locate',
                                             'cl_verbose_set'),
-                                    next_label=_("Perform"))]},
+                                    next_label=_("Run"))]},
         #
         # Обновление конфигурационных файлов (cl-dispatch-conf)
         #
@@ -142,7 +147,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Update settings"),
             # иконка для графической консоли
-            'image': 'edit-find-replace,computer',
+            'image': 'calculate-core-dispatch,edit-find-replace,computer',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -158,8 +163,7 @@ class Wsdl(WsdlBase):
             'native_error': (VariableError, DataVarsError,
                              setup_package.SetupPackageError),
             # значения по умолчанию для переменных этого метода
-            'setvars': {'cl_action!': 'dispatch',
-                        'cl_dispatch_conf!': 'usenew'},
+            'setvars': {'cl_action!': 'dispatch'},
             # описание груп (список лямбда функций)
             'groups': []},
         #
@@ -173,7 +177,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Show Certificates"),
             # иконка для графической консоли
-            'image': 'certificate-server,application-certificate',
+            'image': 'calculate-core-view-cert,certificate-server,'
+                     'application-certificate',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -239,8 +244,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Show Groups"),
             # иконка для графической консоли
-            'image': 'user-group-properties,view-certificate-import,'
-                     'application-certificate',
+            'image': 'calculate-core-group-show,user-group-properties,'
+                     'view-certificate-import,application-certificate',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -416,7 +421,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Show Requests"),
             # иконка для графической консоли
-            'image': 'view-certificate-import,application-certificate',
+            'image': 'calculate-core-request-show,view-certificate-import,'
+                     'application-certificate',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -555,7 +561,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Setup Variables"),
             # иконка для графической консоли
-            'image': 'applications-versioncontrol,'
+            'image': 'calculate-core-variables,applications-versioncontrol,'
                      'text-x-preview,text-x-makefile',
             # метод в графической консоли
             'gui': True,
@@ -588,7 +594,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("View Variables"),
             # иконка для графической консоли
-            'image': 'application-system',
+            'image': None,
             # метод в графической консоли
             'gui': False,
             # консольная команда
@@ -622,7 +628,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Custom Action"),
             # иконка для графической консоли
-            'image': 'gnome-desktop-config,desktop-config',
+            'image': 'calculate-core-custom,gnome-desktop-config,desktop-config',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -648,7 +654,7 @@ class Wsdl(WsdlBase):
                                         'ur_core_login', 'cl_core_arch_machine',
                                         'cl_templates_locate',
                                         'cl_dispatch_conf'),
-                                    next_label=_("Perform"))]},
+                                    next_label=_("Run"))]},
         #
         # перезапустить сервис calculate core
         #
@@ -660,7 +666,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Restart calculate-core"),
             # иконка для графической консоли
-            'image': 'view-refresh',
+            'image': 'calculate-core-restart,view-refresh',
             # метод в графической консоли
             'gui': True,
             # консольная команда
@@ -677,5 +683,73 @@ class Wsdl(WsdlBase):
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'restart'},
             # описание груп (список лямбда функций)
-            'groups': []}
+            'groups': []},
+        #
+        # создание резервной копии настроек
+        #
+        {
+            # идентификатор метода
+            'method_name': "backup",
+            # категория метода
+            'category':__('Backup'),
+            # заголовок метода
+            'title': __("Backup"),
+            # иконка для графической консоли
+            'image': 'calculate-backup',
+            # метод в графической консоли
+            'gui': True,
+            # консольная команда
+            'command': 'cl-backup',
+            # права для запуска метода
+            'rights': ['backup'],
+            # объект содержащий модули для действия
+            'logic': {'Backup': Backup},
+            # описание действия
+            'action': ClBackupAction,
+            # объект переменных
+            'datavars': "core",
+            'native_error': (BackupError, VariableError, DataVarsError),
+            # значения по умолчанию для переменных этого метода
+            'setvars': {'cl_action!': Actions.Backup},
+            # описание груп (список лямбда функций)
+            'groups': [
+                lambda group: group(_("System backup"),
+                                    normal=('cl_backup_verbose_set',),
+                                    next_label=_("Run"))]},
+        #
+        # восстановление настроек из резервной копии
+        #
+        {
+            # идентификатор метода
+            'method_name': "backup_restore",
+            # категория метода
+            'category':__('Backup'),
+            # заголовок метода
+            'title': __("Restore"),
+            # иконка для графической консоли
+            'image': 'calculate-backup-restore',
+            # метод в графической консоли
+            'gui': True,
+            # консольная команда
+            'command': 'cl-backup-restore',
+            # права для запуска метода
+            'rights': ['backup'],
+            # объект содержащий модули для действия
+            'logic': {'Backup': Backup},
+            # описание действия
+            'action': ClBackupRestoreAction,
+            # объект переменных
+            'datavars': "core",
+            'native_error': (BackupError, VariableError, DataVarsError),
+            # значения по умолчанию для переменных этого метода
+            'setvars': {'cl_action!': Actions.BackupRestore,
+                        'core.cl_backup_action': Actions.Restore},
+            # описание груп (список лямбда функций)
+            'groups': [
+            lambda group: group(_("System restore"),
+                                normal=('cl_backup_verbose_set',),
+                                brief=('cl_backup_file', 'cl_backup_time'),
+                                next_label=_("Run"))],
+            'brief': {'next': __("Run"),
+                      'name': __("System restore")}},
     ]
